@@ -12,93 +12,71 @@
 
 using namespace Editor;
 
-ConjugationWidget::ConjugationWidget(QWidget *parent) : QWidget(parent)
+ConjugationWidget::ConjugationWidget(QWidget *parent)
+    : QWidget(parent)
 {
-    m_doc = 0;
-    m_entry = 0;
-    m_identifier = -1;
-
     setupUi(this);
 
     connect(nextTenseButton, &QPushButton::clicked, this, &ConjugationWidget::slotNextTense);
     connect(tenseComboBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &ConjugationWidget::slotTenseSelected);
     connect(tenseComboBox->lineEdit(), SIGNAL(editingFinished()), SLOT(tenseEditingFinished()));
 
-    m_conjugationLineEdits[KEduVocWordFlag::First | KEduVocWordFlag::Singular]
-        = singularFirstPersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Second | KEduVocWordFlag::Singular]
-        = singularSecondPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::First | KEduVocWordFlag::Singular] = singularFirstPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Second | KEduVocWordFlag::Singular] = singularSecondPersonLineEdit;
 
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Masculine | KEduVocWordFlag::Singular]
-        = singularThirdMalePersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Feminine | KEduVocWordFlag::Singular]
-        = singularThirdFemalePersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Neuter | KEduVocWordFlag::Singular]
-        = singularThirdNeutralPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Masculine | KEduVocWordFlag::Singular] = singularThirdMalePersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Feminine | KEduVocWordFlag::Singular] = singularThirdFemalePersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Neuter | KEduVocWordFlag::Singular] = singularThirdNeutralPersonLineEdit;
 
-    m_conjugationLineEdits[KEduVocWordFlag::First | KEduVocWordFlag::Dual]
-        = dualFirstPersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Second | KEduVocWordFlag::Dual]
-        = dualSecondPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::First | KEduVocWordFlag::Dual] = dualFirstPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Second | KEduVocWordFlag::Dual] = dualSecondPersonLineEdit;
 
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Masculine | KEduVocWordFlag::Dual]
-        = dualThirdMalePersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Feminine | KEduVocWordFlag::Dual]
-        = dualThirdFemalePersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Neuter | KEduVocWordFlag::Dual]
-        = dualThirdNeutralPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Masculine | KEduVocWordFlag::Dual] = dualThirdMalePersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Feminine | KEduVocWordFlag::Dual] = dualThirdFemalePersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Neuter | KEduVocWordFlag::Dual] = dualThirdNeutralPersonLineEdit;
 
-    m_conjugationLineEdits[KEduVocWordFlag::First | KEduVocWordFlag::Plural]
-        = pluralFirstPersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Second | KEduVocWordFlag::Plural]
-        = pluralSecondPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::First | KEduVocWordFlag::Plural] = pluralFirstPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Second | KEduVocWordFlag::Plural] = pluralSecondPersonLineEdit;
 
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Masculine | KEduVocWordFlag::Plural]
-        = pluralThirdMalePersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Feminine | KEduVocWordFlag::Plural]
-        = pluralThirdFemalePersonLineEdit;
-    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Neuter | KEduVocWordFlag::Plural]
-        = pluralThirdNeutralPersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Masculine | KEduVocWordFlag::Plural] = pluralThirdMalePersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Feminine | KEduVocWordFlag::Plural] = pluralThirdFemalePersonLineEdit;
+    m_conjugationLineEdits[KEduVocWordFlag::Third | KEduVocWordFlag::Neuter | KEduVocWordFlag::Plural] = pluralThirdNeutralPersonLineEdit;
 
-    foreach(const KEduVocWordFlags & index, m_conjugationLineEdits.keys()) {
-        connect(m_conjugationLineEdits.value(index), &QLineEdit::textChanged, this, &ConjugationWidget::textChanged);
+    for (auto iter = m_conjugationLineEdits.cbegin(); iter != m_conjugationLineEdits.cend(); ++iter) {
+        connect(m_conjugationLineEdits.value(iter.key()), &QLineEdit::textChanged, this, &ConjugationWidget::textChanged);
     }
 }
 
-
-void ConjugationWidget::textChanged(const QString& text)
+void ConjugationWidget::textChanged(const QString &text)
 {
-    int valueIndex = m_conjugationLineEdits.values().indexOf(qobject_cast<QLineEdit*>(sender()));
-    int key = m_conjugationLineEdits.keys().value(valueIndex);
+    int key = m_conjugationLineEdits.key(qobject_cast<QLineEdit *>(sender()));
     KEduVocTranslation *translation = m_entry->translation(m_identifier);
     KEduVocConjugation conjugation = translation->getConjugation(tenseComboBox->currentText());
     conjugation.setConjugation(text, (KEduVocWordFlag::Flags)key);
     translation->setConjugation(tenseComboBox->currentText(), conjugation);
 }
 
-
 void ConjugationWidget::slotTenseSelected(int sel)
 {
     Q_UNUSED(sel);
     updateEntries();
 }
 
-
 void ConjugationWidget::updateEntries()
 {
     m_lastTenseSelection = tenseComboBox->currentText();
     KEduVocConjugation conjugation = m_entry->translation(m_identifier)->getConjugation(m_lastTenseSelection);
-    foreach(KEduVocWordFlags flags, m_conjugationLineEdits.keys()) {
+    for (auto iter = m_conjugationLineEdits.cbegin(); iter != m_conjugationLineEdits.cend(); ++iter) {
         QString text;
-        if (conjugation.keys().contains(flags)) {
-            text = conjugation.conjugation(flags).text();
+        if (conjugation.keys().contains(iter.key())) {
+            text = conjugation.conjugation(iter.key()).text();
         }
 
-        m_conjugationLineEdits[flags]->setText(text);
+        m_conjugationLineEdits[iter.key()]->setText(text);
     }
 }
 
-void ConjugationWidget::setTranslation(KEduVocExpression * entry, int identifier)
+void ConjugationWidget::setTranslation(KEduVocExpression *entry, int identifier)
 {
     tenseComboBox->clear();
     tenseComboBox->completionObject()->clear();
@@ -121,14 +99,13 @@ void ConjugationWidget::setTranslation(KEduVocExpression * entry, int identifier
     }
 
     setEnabled(true);
-    if (entry->translation(m_identifier)->wordType()
-            && entry->translation(m_identifier)->wordType()->wordType() & KEduVocWordFlag::Verb) {
+    if (entry->translation(m_identifier)->wordType() && entry->translation(m_identifier)->wordType()->wordType() & KEduVocWordFlag::Verb) {
         updateVisiblePersons();
         updateEntries();
     }
 }
 
-void ConjugationWidget::setDocument(KEduVocDocument * doc)
+void ConjugationWidget::setDocument(KEduVocDocument *doc)
 {
     m_doc = doc;
     tenseComboBox->clear();
@@ -228,7 +205,7 @@ void ConjugationWidget::showWidgets(bool tenses, bool singular, bool dual, bool
 
 void ConjugationWidget::tenseEditingFinished()
 {
-    const QStringList& oldTenses = m_doc->identifier(m_identifier).tenseList();
+    const QStringList &oldTenses = m_doc->identifier(m_identifier).tenseList();
     if (!oldTenses.contains(tenseComboBox->currentText())) {
         // add a new tense
         m_doc->identifier(m_identifier).setTense(oldTenses.count(), tenseComboBox->currentText());
